=====================================
README for HydraTK Security extension
=====================================

| Security extension provides interface to security testing tools.

| Following applications are supported.

* MSF - MetaSploit Framework
* ZAP - Zed Attack Proxy